% CEEJ02 Example of the application of the cross-entropy method for single-
%    objective optimization (two decision variables, unconstrained).
%
%   Objective function: f(x) = x1^2 + 2*x2^2 - 0.3*cos(3*pi*x1) - 0.4*cos(4*pi*x2)
%   Decision variable:   -10 <= x1 <= 10
%                        -10 <= x2 <= 10
%   Unconstrained
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

% Clearing workspace and console
clear all; clc;

% Setting options
options = ceoptdef('ConvergenceLimit', 1e-5, 'SmoothingType', 'fixed', ...
                   'Display', 'iter');

% Defining objective function
f = @(x) x(:, 1).^2 + 2.*x(:, 2).^2 - 0.3.*cos(3.*pi.*x(:, 1)) - 0.4.*cos(4.*pi.*x(:, 2));

% Defining variables limits
l = [-10, -10]; u = [10, 10];

% Applying the optimization method
[X_opt, y_opt] = soce(f, l, u, options, [], []);

