% CEEJ03 Example of the application of the cross-entropy method for single-
%    objetive optimization (two decision variables, constrained).
%
%   Objective function: f(x) = x1^2 + (x2 - 5)^2
%   Decision variable:   -50 <= x1 <= 50
%                        -50 <= x2 <= 50
%   Constraints:         g1(x) = 1 - x1/2 <= 0
%                        g2(x) = 1 - 0.3*x2/x1 <= 0
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

% Clearing workspace and console
clear all; clc;

% Setting options
options = ceoptdef('ConvergenceLimit', 1e-10, 'PopulationSize', 500, ...
                   'Display', 'iter');

% Defining objective function
f = @(x) x(:, 1).^2 + (x(:, 2) - 5).^2;

% Defining lower and upper bounds
l = [-50, -50]; u = [50, 50];

% Defining constraints
g = @(x) [ 1 - x(:, 1)./2, 1 - 0.3.*x(:, 2)./x(:, 1)];

% Defining penalty factors
gamma = [100, 100];

% Applying the optimization method
[X_opt, y_opt] = soce(f, l, u, options, g, gamma);
