% CEEJ11 Example of the application of the cross-entropy method for two-
%    objetives optimization (one decision variables, unconstrained) [MOP1].
%
%   Objective functions: f1(x) = x^2;
%                        f2(x) = (x - 2)^ 2
%   Decision variable:   -1e3 <= x <= 1e3
%   Unconstrained
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

% Clearing console and workspace
clc; clear all;

% Setting options
options = ceoptdef('Generations', 100, ...
                   'PopulationSize', 500, ...
                   'EliteRatio', 0.2, ...
                   'Display', 'iter');

% Defining objective function
f = @(x) [x.^2, (x - 2).^2];

% Executing the optimization process
[PS, PF] = moce(f, -1e3, 1e3, options);

% Getting the true Pareto front from a file data
TPF = truepf('MOP1');
 
% Plotting the Pareto's front
figure;
subplot(1, 2, 1);
plot(PF(:, 1), PF(:, 2), '*k', TPF(:, 1), TPF(:, 2), '-r');
title('Pareto''s front');
xlabel('f_1(x)'); ylabel('f_2(x)'); grid;
subplot(1, 2, 2);
plot(PS, zeros(size(PS)), '*k')
title('Pareto''s set');
xlabel('x'); ylabel(''); grid;

% Computing hyperarea
p0 = [5 5];
HA = pfm_ha(PF, p0);
fprintf('Pareto front metrics\n');
fprintf('   Hyperarea = %f\n', HA);

% Computing hyperarea ratio
HR = pfm_hr(PF, TPF, p0);
fprintf('   Hyperarea ration = %.4f\n', HR);