% CEEJ12 Example of the application of the cross-entropy method for
%    2-objetives optimization (3 decision variables, unconstrained) [MOP2].
%
%   Objective functions: f1(x) = 1 - exp(-sum(xi - 1/sqrt(3)))
%                        f2(x) = 1 - exp(-sum(xi + 1/sqrt(3)))
%   Decision variable:   -4 <= x1 <= 4
%                        -4 <= x2 <= 4
%                        -4 <= x3 <= 4
%   Unconstrained
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

% Clearing console and workspace
clc; clear all;

% Setting options
options = ceoptdef('Generations', 200, ...
                   'PopulationSize', 1000, ...
                   'EliteRatio', 0.35, ...
                   'HistogramIntervals', 10, ...
                   'Display', 'iter');

% Defining objective functions
f1 = ['1 - exp(-((x(:, 1) - 1/sqrt(3)).^2 + ', ...
      '(x(:, 2) - 1/sqrt(3)).^2 + (x(:, 3) - 1/sqrt(3)).^2))']; 
f2 = ['1 - exp(-((x(:, 1) + 1/sqrt(3)).^2 + ', ...
      '(x(:, 2) + 1/sqrt(3)).^2 + (x(:, 3) + 1/sqrt(3)).^2))'];
f = inline(['[', f1, ', ', f2, ']']);

% Executing the optimization process
[PS, PF] = moce(f, [-4 -4 -4], [4 4 4], options);

% Getting the true Pareto front from a file data
TPF = truepf('MOP2');

% Plotting the Pareto's front
figure;
subplot(1, 2, 1);
plot(TPF(:, 1), TPF(:, 2), '-r', PF(:, 1), PF(:, 2), '.k');
title('Pareto''s front');
xlabel('f_1(x_1, x_2, x_3)'); ylabel('f_2(x_1, x_2, x_3)'); grid;
subplot(1, 2, 2);
plot3(PS(:, 1), PS(:, 2), PS(:, 3), '.k');
title('Pareto''s set');
xlabel('x_1'); ylabel('x_2'); zlabel('x_3'); grid;
view([0.3777, 1, 0.3777]);

