% CEEJ13 Example of the application of the cross-entropy method for
%    2-objetives optimization (2 decision variables, constrained) [MOP-C4].
%
%   Objective functions: f1(x) = x1
%                        f2(x) = x2
%   Decision variable:   0 <= x1 <= pi
%                        0 <= x2 <= pi
%   Constraints:         g(x) = -x1^2 - x2^2 + 1 + 0.1*cos(16*atan(x1/x2)) <= 0
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

% Clearing console and workspace
clc; clear all;

% Setting options
options = ceoptdef('Generations', 200, ...
                   'PopulationSize', 5000, ...
                   'EliteRatio', 0.35, ...
                   'HistogramIntervals', 10, ...
                   'Display', 'iter');

% Defining objective functions
f = @(x) [x(:, 1), x(:, 2)];

% Defining constraints and penalty factors
g = @(x) - x(:, 1).^2 - x(:, 2).^2 + 1 + 0.1.*cos(16.*atan(x(:, 1)./x(:, 2)));
gamma = [10];

% Excuting the optimization process
[PS, PF] = moce(f, [0 0], [pi pi], options, g, gamma);

% Getting the true Pareto front from a file data
TPF = truepf('MOPC4');

% Plotting the Pareto's front
figure;
plot(TPF(:, 1), TPF(:, 2), '-r', PF(:, 1), PF(:, 2), '.k');
title('Pareto''s front');
xlabel('f_1(x_1, x_2)'); ylabel('f_2(x_1, x_2)');
grid;
axis equal;

