function d = prank(PF)
% PRANK Pareto ranking
%   Evaluate the Pareto rank (i.e., the number of points which dominate the
%   point) for every point in the given set.
%
%   Syntax: d = PRANK(PF)
%
%   Arguments:
%     PF [real, n-by-m matrix] Pareto front of n objectives and m points
%
%   Returns:
%     d [integer, n-values column vector] Pareto rank of every point
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%
%   Based on function "hypervolume" v. 1.0 by Yi Cao at Cranfield 
%   University on 20 April 2008

   d = zeros(size(PF, 1), 1);
   for i = 1 : size(PF, 1)
      d(i, 1) = sum(all(repmat(PF(i, :), size(PF, 1), 1) >= PF, 2)) - 1;
   end
end
