function TPF = truepf(problem)
%TRUEPF True Pareto front
%   Returns the true Pareto front of some standard test problems.
%
%   Syntax:
%      TPF = TRUEPF(problem)
%
%   Arguments:
%      PROBLEM {'MOP1'|'MOP2'|'MOP3'|'MOP4'|'MOP6'|'MOP6a'|'MOPC4'|'ZDT1'|
%               'ZDT2'|'ZDT3'|'WFG1'|'WFG2'|'WFG3'|'WFG4'|'WFG5'|'WFG6'|
%               'WFG7'|'WFG8'|'WFG9} Problem name
%
%   Outputs:
%      TPF [real q-by-m matrix] True Pareto front.
%
%   Cross-Entropy Optimisation Toolbox
%   (c) 2018, GAMHE <http://www.gamhe.eu> and CEFAS <http://cefas.umcc.cu>
%

    % Verifying the arguments values
    problemNames = {'MOP1', 'MOP2', 'MOP3', 'MOP4', 'MOP6', 'MOP6a', ...
                    'MOPC4', 'ZDT1', 'ZDT2', 'ZDT3', 'WFG1', 'WFG2',  ...
                    'WFG3', 'WFG4', 'WFG5', 'WFG6', 'WFG7', 'WFG8', 'WFG9'};
    if isempty(problem), error('Argument ''problem'' should not be empty.'); end
    if ~ischar(problem), error('Argument ''problem'' should be a string.'); end
    flag = false;
    for i = 1 : length(problemNames)
        if strcmpi(problem, problemNames{i}), flag = true; end
    end
    if (~flag), error('Wrogn value for algument ''problem''.'); end
    
    % Loading TPF
    s = load('tpf.mat', problem);
    TPF = getfield(s, problem);
end

